package algorithms;

import executor.Constants;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import objects.Bone;
import objects.PoseJointCoordinates;
import objects.Joint;
import objects.MotionJointCoordinates;
import objects.Skeleton;
import objects.Trajectory;
import objects.Trajectory3d;
import objects.Triple;

public class MotionLoaderJointCoordinates extends MotionLoader {

    @Override
    public MotionJointCoordinates loadMotion(File fileAMC) throws IOException {
        Skeleton skeleton = new Skeleton();
        skeleton.readASF(Constants.prototypicalFileASF.getPath());
        skeleton.readAMC(fileAMC.getPath());
        List<Trajectory> trajectories = new ArrayList();
        for (Bone bone : skeleton.getBones()) {
            Trajectory3d trajectory3d = skeleton.getTrajectory3d(bone.getName());
            List<Triple> positions3d = trajectory3d.getPositions();
            List<Triple> positions = new ArrayList();
            for (int l = 0; l < trajectory3d.getPositions().size(); l++) {
                positions.add(positions3d.get(l));
            }
            trajectories.add(new Trajectory(trajectory3d.getName(), positions));
        }
        List<PoseJointCoordinates> poses = new ArrayList();
        for (int l = 0; l < skeleton.getNumberOfPoses() - 1; l++) {
            List<Joint> joints = new ArrayList();
            joints.add(new Joint("root", skeleton.getRoot().getPositions().get(l)));
            for (Bone bone : skeleton.getBones()) {
                Trajectory trajectory = trajectories.get(0);
                for (Trajectory traj : trajectories) {
                    if (traj.getName().equals(bone.getName())) {
                        trajectory = traj;
                    }
                }
                joints.add(new Joint(bone.getName(), trajectory.getPosition(l)));
            }
            poses.add(new PoseJointCoordinates(joints));
        }
        return new MotionJointCoordinates(fileAMC.getName().split("\\.")[0], poses);
    }
}
